@@ -11,12 +11,12 @@ class Clean:
 		self._base = CommandsGroup("clean", core, parent)
 
 	@property
-	def eventLogging(self):
-		"""eventLogging commands group. 0 Sub-classes, 1 commands."""
-		if not hasattr(self, '_eventLogging'):
-			from .Clean_.EventLogging import EventLogging
-			self._eventLogging = EventLogging(self._core, self._base)
-		return self._eventLogging
+	def elogging(self):
+		"""elogging commands group. 0 Sub-classes, 1 commands."""
+		if not hasattr(self, '_elogging'):
+			from .Clean_.Elogging import Elogging
+			self._elogging = Elogging(self._core, self._base)
+		return self._elogging
 
 	@property
 	def connection(self):
