@@ -19,12 +19,12 @@ class Tpcset:
 		return self._pconfig
 
 	@property
-	def preCondition(self):
-		"""preCondition commands group. 0 Sub-classes, 4 commands."""
-		if not hasattr(self, '_preCondition'):
-			from .Tpcset_.PreCondition import PreCondition
-			self._preCondition = PreCondition(self._core, self._base)
-		return self._preCondition
+	def precondition(self):
+		"""precondition commands group. 0 Sub-classes, 4 commands."""
+		if not hasattr(self, '_precondition'):
+			from .Tpcset_.Precondition import Precondition
+			self._precondition = Precondition(self._core, self._base)
+		return self._precondition
 
 	def clone(self) -> 'Tpcset':
 		"""Clones the group by creating new object from it and its whole existing sub-groups
