@@ -11,12 +11,12 @@ class Carrier:
 		self._base = CommandsGroup("carrier", core, parent)
 
 	@property
-	def transportBlock(self):
-		"""transportBlock commands group. 2 Sub-classes, 0 commands."""
-		if not hasattr(self, '_transportBlock'):
-			from .Carrier_.TransportBlock import TransportBlock
-			self._transportBlock = TransportBlock(self._core, self._base)
-		return self._transportBlock
+	def tblock(self):
+		"""tblock commands group. 2 Sub-classes, 0 commands."""
+		if not hasattr(self, '_tblock'):
+			from .Carrier_.Tblock import Tblock
+			self._tblock = Tblock(self._core, self._base)
+		return self._tblock
 
 	@property
 	def code(self):
