@@ -11,12 +11,12 @@ class Fsimulator:
 		self._base = CommandsGroup("fsimulator", core, parent)
 
 	@property
-	def insertionLoss(self):
-		"""insertionLoss commands group. 0 Sub-classes, 1 commands."""
-		if not hasattr(self, '_insertionLoss'):
-			from .Fsimulator_.InsertionLoss import InsertionLoss
-			self._insertionLoss = InsertionLoss(self._core, self._base)
-		return self._insertionLoss
+	def iloss(self):
+		"""iloss commands group. 0 Sub-classes, 1 commands."""
+		if not hasattr(self, '_iloss'):
+			from .Fsimulator_.Iloss import Iloss
+			self._iloss = Iloss(self._core, self._base)
+		return self._iloss
 
 	def clone(self) -> 'Fsimulator':
 		"""Clones the group by creating new object from it and its whole existing sub-groups
