@@ -54,14 +54,14 @@ class UeCapability:
 			- Phys_Layer_Cat_R_9: int: E-DCH physical layer category of the UE for release 9 call setup Range: 8 to 9
 			- Phys_Layer_Cat_R_7: int: E-DCH physical layer category of the UE for release 7 call setup Range: 7 to 7
 			- Phys_Layer_Cat_R_11: int: E-DCH physical layer category of the UE for release 11 call setup
-			- Erg_Chbi_Ctrl: enums.YesNoStatus: NO | YES Indicates whether the UE supports common E-RGCH-based interference control in CELL_FACH state"""
+			- Ergch_Bic_Trl: enums.YesNoStatus: NO | YES Indicates whether the UE supports common E-RGCH-based interference control in CELL_FACH state"""
 		__meta_args_list = [
 			ArgStruct.scalar_enum('Hsupa', enums.YesNoStatus),
 			ArgStruct.scalar_int('Phys_Layer_Cat_R_6'),
 			ArgStruct.scalar_int('Phys_Layer_Cat_R_9'),
 			ArgStruct.scalar_int('Phys_Layer_Cat_R_7'),
 			ArgStruct.scalar_int('Phys_Layer_Cat_R_11'),
-			ArgStruct.scalar_enum('Erg_Chbi_Ctrl', enums.YesNoStatus)]
+			ArgStruct.scalar_enum('Ergch_Bic_Trl', enums.YesNoStatus)]
 
 		def __init__(self):
 			StructBase.__init__(self, self)
@@ -70,7 +70,7 @@ class UeCapability:
 			self.Phys_Layer_Cat_R_9: int = None
 			self.Phys_Layer_Cat_R_7: int = None
 			self.Phys_Layer_Cat_R_11: int = None
-			self.Erg_Chbi_Ctrl: enums.YesNoStatus = None
+			self.Ergch_Bic_Trl: enums.YesNoStatus = None
 
 	# noinspection PyTypeChecker
 	def get_hsupa(self) -> HsupaStruct:
@@ -97,10 +97,10 @@ class UeCapability:
 			- Phys_Layer_Cat_R_10: int: HS-DSCH physical layer category of the UE for release 10 call setup Range: 29 to 32
 			- Ma_Cehs: enums.YesNoStatus: NO | YES Indicates whether the UE supports the MAC-ehs
 			- Phys_Layer_Cat_R_11: int: HS-DSCH physical layer category of the UE for release 11 call setup
-			- Hsd_Pcch_Poff_Ext: enums.YesNoStatus: NO | YES Indicates whether the UE supports the values 9 and 10 of deltaACK, deltaNACK and deltaCQI power offset
+			- Hsdpcch_Poff_Ext: enums.YesNoStatus: NO | YES Indicates whether the UE supports the values 9 and 10 of deltaACK, deltaNACK and deltaCQI power offset
 			- Drx_Op_2nd_C: enums.YesNoStatus: NO | YES Indicates whether the UE supports HS-DSCH DRX operation with second DRX cycle in CELL_FACH state
-			- Nb_Trg_Hsd_Pcch: enums.YesNoStatus: NO | YES Indicates whether the UE supports NodeB triggered HS-DPCCH transmission in CELL_FACH state
-			- Hsd_Pcch_Ov_Hd_Rd: enums.YesNoStatus: NO | YES Indicates whether the UE supports HS-DPCCH overhead reduction"""
+			- Nb_Trg_Hsdpcch: enums.YesNoStatus: NO | YES Indicates whether the UE supports NodeB triggered HS-DPCCH transmission in CELL_FACH state
+			- Hsdpcch_Ov_Hd_Rd: enums.YesNoStatus: NO | YES Indicates whether the UE supports HS-DPCCH overhead reduction"""
 		__meta_args_list = [
 			ArgStruct.scalar_enum('Hs_Pdsch', enums.YesNoStatus),
 			ArgStruct.scalar_int('Dl_Cap_Hsd_Sch'),
@@ -115,10 +115,10 @@ class UeCapability:
 			ArgStruct.scalar_int('Phys_Layer_Cat_R_10'),
 			ArgStruct.scalar_enum('Ma_Cehs', enums.YesNoStatus),
 			ArgStruct.scalar_int('Phys_Layer_Cat_R_11'),
-			ArgStruct.scalar_enum('Hsd_Pcch_Poff_Ext', enums.YesNoStatus),
+			ArgStruct.scalar_enum('Hsdpcch_Poff_Ext', enums.YesNoStatus),
 			ArgStruct.scalar_enum('Drx_Op_2nd_C', enums.YesNoStatus),
-			ArgStruct.scalar_enum('Nb_Trg_Hsd_Pcch', enums.YesNoStatus),
-			ArgStruct.scalar_enum('Hsd_Pcch_Ov_Hd_Rd', enums.YesNoStatus)]
+			ArgStruct.scalar_enum('Nb_Trg_Hsdpcch', enums.YesNoStatus),
+			ArgStruct.scalar_enum('Hsdpcch_Ov_Hd_Rd', enums.YesNoStatus)]
 
 		def __init__(self):
 			StructBase.__init__(self, self)
@@ -135,10 +135,10 @@ class UeCapability:
 			self.Phys_Layer_Cat_R_10: int = None
 			self.Ma_Cehs: enums.YesNoStatus = None
 			self.Phys_Layer_Cat_R_11: int = None
-			self.Hsd_Pcch_Poff_Ext: enums.YesNoStatus = None
+			self.Hsdpcch_Poff_Ext: enums.YesNoStatus = None
 			self.Drx_Op_2nd_C: enums.YesNoStatus = None
-			self.Nb_Trg_Hsd_Pcch: enums.YesNoStatus = None
-			self.Hsd_Pcch_Ov_Hd_Rd: enums.YesNoStatus = None
+			self.Nb_Trg_Hsdpcch: enums.YesNoStatus = None
+			self.Hsdpcch_Ov_Hd_Rd: enums.YesNoStatus = None
 
 	# noinspection PyTypeChecker
 	def get_hsdpa(self) -> HsdpaStruct:
@@ -263,7 +263,7 @@ class UeCapability:
 			- Ps_Handover_Gan: enums.YesNoStatus: NO | YES Indicates whether the UE supports PS handover to GAN
 			- Eutra_Fdd: enums.YesNoStatus: NO | YES Indicates whether the UE supports E-UTRA FDD
 			- Eutra_Inter_Rat: enums.YesNoStatus: NO | YES Indicates whether the UE supports inter-RAT E-UTRA handover
-			- U_2_Eutra_Rrc_Idle: enums.YesNoStatus: NO | YES Indicates whether the UE supports cell reselection from UTRA CELL_PCH or URA_PCH to E-UTRA RRC_IDLE
+			- U_2_Eu_Tra_Rrci_Dle: enums.YesNoStatus: NO | YES Indicates whether the UE supports cell reselection from UTRA CELL_PCH or URA_PCH to E-UTRA RRC_IDLE
 			- Prio_Res_Utran: enums.YesNoStatus: NO | YES Indicates whether the UE supports priority reselection in UTRAN
 			- Eutra_Fdd_Cfch: enums.YesNoStatus: NO | YES Indicates whether the UE supports E-UTRA measurements and reporting for CELL_FACH for E-UTRA FDD
 			- Eutra_Tdd_Cdch: enums.YesNoStatus: NO | YES Indicates whether the UE supports E-UTRA measurements and reporting for CELL_FACH for E-UTRA TDD
@@ -285,7 +285,7 @@ class UeCapability:
 			ArgStruct.scalar_enum('Ps_Handover_Gan', enums.YesNoStatus),
 			ArgStruct.scalar_enum('Eutra_Fdd', enums.YesNoStatus),
 			ArgStruct.scalar_enum('Eutra_Inter_Rat', enums.YesNoStatus),
-			ArgStruct.scalar_enum('U_2_Eutra_Rrc_Idle', enums.YesNoStatus),
+			ArgStruct.scalar_enum('U_2_Eu_Tra_Rrci_Dle', enums.YesNoStatus),
 			ArgStruct.scalar_enum('Prio_Res_Utran', enums.YesNoStatus),
 			ArgStruct.scalar_enum('Eutra_Fdd_Cfch', enums.YesNoStatus),
 			ArgStruct.scalar_enum('Eutra_Tdd_Cdch', enums.YesNoStatus),
@@ -309,7 +309,7 @@ class UeCapability:
 			self.Ps_Handover_Gan: enums.YesNoStatus = None
 			self.Eutra_Fdd: enums.YesNoStatus = None
 			self.Eutra_Inter_Rat: enums.YesNoStatus = None
-			self.U_2_Eutra_Rrc_Idle: enums.YesNoStatus = None
+			self.U_2_Eu_Tra_Rrci_Dle: enums.YesNoStatus = None
 			self.Prio_Res_Utran: enums.YesNoStatus = None
 			self.Eutra_Fdd_Cfch: enums.YesNoStatus = None
 			self.Eutra_Tdd_Cdch: enums.YesNoStatus = None
@@ -348,12 +348,12 @@ class UeCapability:
 			- Tx_Bits_All: int: Maximum number of bits of all transport blocks being transmitted at an arbitrary time instant. All bits are considered. Range: 640 bits to 163840 bits, Unit: bits
 			- Tx_Bits_Conv: int: Maximum number of bits of all transport blocks being transmitted at an arbitrary time instant. Only convolutionally coded bits are considered. Range: 640 bits to 163840 bits, Unit: bits
 			- Tx_Bits_Turbo: int: Maximum number of bits of all transport blocks being transmitted at an arbitrary time instant. Only turbo coded bits are considered. Range: 640 bits to 163840 bits, Unit: bits
-			- Dpdch_Bits: int: Maximum number of DPDCH bits the UE can transmit in 10 ms. The value applies to UE operation in non-compressed mode (if the value is 9600) or in both compressed and non-compressed mode (if the value is ≥9600) . Range: 600 bits to 57600 bits, Unit: bits
+			- Dpd_Ch_Bits: int: Maximum number of DPDCH bits the UE can transmit in 10 ms. The value applies to UE operation in non-compressed mode (if the value is 9600) or in both compressed and non-compressed mode (if the value is ≥9600) . Range: 600 bits to 57600 bits, Unit: bits
 			- Dpcch_Dtx: enums.YesNoStatus: NO | YES Support of discontinuous uplink DPCCH transmission
 			- Slot_Format_4: enums.YesNoStatus: NO | YES Support of DPCCH slot format 4
 			- Common_Edch: enums.YesNoStatus: NO | YES Support of common E-DCH
 			- Edpcch_Pwr_Boost: enums.YesNoStatus: NO | YES Support of E-DPCCH power boosting
-			- Edpd_Ch_Pwr_Intrpl: enums.YesNoStatus: NO | YES Support of E-DPCCH power interpolation
+			- Edpdch_Pwr_Interpol: enums.YesNoStatus: NO | YES Support of E-DPCCH power interpolation
 			- Dtx_Enh: enums.YesNoStatus: NO | YES Support of DTX enhancements
 			- Srv_Edc_Hcd_Op: enums.YesNoStatus: NO | YES Support of FDD serving E-DCH cell decoupling operation
 			- Rlwo_Fdpch: enums.YesNoStatus: NO | YES Support of FDD radio link without DPCH or F-DPCH"""
@@ -367,12 +367,12 @@ class UeCapability:
 			ArgStruct.scalar_int('Tx_Bits_All'),
 			ArgStruct.scalar_int('Tx_Bits_Conv'),
 			ArgStruct.scalar_int('Tx_Bits_Turbo'),
-			ArgStruct.scalar_int('Dpdch_Bits'),
+			ArgStruct.scalar_int('Dpd_Ch_Bits'),
 			ArgStruct.scalar_enum('Dpcch_Dtx', enums.YesNoStatus),
 			ArgStruct.scalar_enum('Slot_Format_4', enums.YesNoStatus),
 			ArgStruct.scalar_enum('Common_Edch', enums.YesNoStatus),
 			ArgStruct.scalar_enum('Edpcch_Pwr_Boost', enums.YesNoStatus),
-			ArgStruct.scalar_enum('Edpd_Ch_Pwr_Intrpl', enums.YesNoStatus),
+			ArgStruct.scalar_enum('Edpdch_Pwr_Interpol', enums.YesNoStatus),
 			ArgStruct.scalar_enum('Dtx_Enh', enums.YesNoStatus),
 			ArgStruct.scalar_enum('Srv_Edc_Hcd_Op', enums.YesNoStatus),
 			ArgStruct.scalar_enum('Rlwo_Fdpch', enums.YesNoStatus)]
@@ -388,12 +388,12 @@ class UeCapability:
 			self.Tx_Bits_All: int = None
 			self.Tx_Bits_Conv: int = None
 			self.Tx_Bits_Turbo: int = None
-			self.Dpdch_Bits: int = None
+			self.Dpd_Ch_Bits: int = None
 			self.Dpcch_Dtx: enums.YesNoStatus = None
 			self.Slot_Format_4: enums.YesNoStatus = None
 			self.Common_Edch: enums.YesNoStatus = None
 			self.Edpcch_Pwr_Boost: enums.YesNoStatus = None
-			self.Edpd_Ch_Pwr_Intrpl: enums.YesNoStatus = None
+			self.Edpdch_Pwr_Interpol: enums.YesNoStatus = None
 			self.Dtx_Enh: enums.YesNoStatus = None
 			self.Srv_Edc_Hcd_Op: enums.YesNoStatus = None
 			self.Rlwo_Fdpch: enums.YesNoStatus = None
