@@ -23,7 +23,7 @@ class Uplink:
 		"""SCPI: SENSe:WCDMa:SIGNaling<instance>:UL:EIPower \n
 		Snippet: value: float = driver.sense.uplink.get_ei_power() \n
 		Queries the expected initial DPCCH power. \n
-			:return: exp_dpcch_power: Range: -160 dBm to 33 dBm, Unit: dBm
+			:return: exp_dpcchp_ower: Range: -160 dBm to 33 dBm, Unit: dBm
 		"""
 		response = self._core.io.query_str('SENSe:WCDMa:SIGNaling<Instance>:UL:EIPower?')
 		return Conversions.str_to_float(response)
