@@ -81,7 +81,7 @@ class BandClass(Enum):
 
 
 # noinspection SpellCheckingInspection
-class BaseBandBoard(Enum):
+class BasebandBoard(Enum):
 	"""140 Members, BBR1 ... SUW44"""
 	BBR1 = 0
 	BBR11 = 1
@@ -349,7 +349,7 @@ class CmodePatternSelection(Enum):
 
 
 # noinspection SpellCheckingInspection
-class CmserRejectType(Enum):
+class CmSerRejectType(Enum):
 	"""7 Members, ECALl ... SMS"""
 	ECALl = 0
 	ECSMs = 1
